You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@rocketmq.apache.org by "TestBoost (via GitHub)" <gi...@apache.org> on 2024/07/24 02:05:19 UTC
[PR] only initialize all the variables once to speed up test ConsumeMessageConcurrentlyServiceTest [rocketmq]
TestBoost opened a new pull request, #8436:
URL: https://github.com/apache/rocketmq/pull/8436
<!-- Please make sure the target branch is right. In most case, the target branch should be `develop`. -->
### Which Issue(s) This PR Fixes
<!-- Please ensure that the related issue has already been created, and [link this pull request to that issue using keywords](<https://docs.github.com/en/issues/tracking-your-work-with-issues/linking-a-pull-request-to-an-issue#linking-a-pull-request-to-an-issue-using-a-keyword>) to ensure automatic closure. -->
We are not fixing existing issues in this commit.
### Brief Description
<!-- Write a brief description for your pull request to help the maintainer understand the reasons behind your changes. -->
Changes proposed in this pull request:
We put all the initialization of the mocks and variables into the method body of @BeforeAll and @AfterAll. There are two tests in the test class ConsumeMessageConcurrentlyServiceTest. However, these two tests are not affecting each other.
The test runtime can jump from 2.771 s to 1.768 s after applying the changes when run on our machine.
### How Did You Test This Change?
<!-- In order to ensure the code quality of Apache RocketMQ, we expect every pull request to have undergone thorough testing. -->
We just ran this test class in any order and it passes. We ran this test class 10 times and it also passes. We also ran all tests in client module 10 times, and there are no changes for the test results.
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: commits-unsubscribe@rocketmq.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org
Re: [PR] only initialize all the variables once to speed up test ConsumeMessageConcurrentlyServiceTest [rocketmq]
Posted by "RongtongJin (via GitHub)" <gi...@apache.org>.
RongtongJin merged PR #8436:
URL: https://github.com/apache/rocketmq/pull/8436
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: commits-unsubscribe@rocketmq.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org
Re: [PR] only initialize all the variables once to speed up test ConsumeMessageConcurrentlyServiceTest [rocketmq]
Posted by "codecov-commenter (via GitHub)" <gi...@apache.org>.
codecov-commenter commented on PR #8436:
URL: https://github.com/apache/rocketmq/pull/8436#issuecomment-2246751361
## [Codecov](https://app.codecov.io/gh/apache/rocketmq/pull/8436?dropdown=coverage&src=pr&el=h1&utm_medium=referral&utm_source=github&utm_content=comment&utm_campaign=pr+comments&utm_term=apache) Report
All modified and coverable lines are covered by tests :white_check_mark:
> Project coverage is 45.48%. Comparing base [(`6fb455a`)](https://app.codecov.io/gh/apache/rocketmq/commit/6fb455a1d4dc7416c81ad447fbfe4f9429765609?dropdown=coverage&el=desc&utm_medium=referral&utm_source=github&utm_content=comment&utm_campaign=pr+comments&utm_term=apache) to head [(`604b60b`)](https://app.codecov.io/gh/apache/rocketmq/commit/604b60bc755ba77f95a284a7721f1d0b215b12d0?dropdown=coverage&el=desc&utm_medium=referral&utm_source=github&utm_content=comment&utm_campaign=pr+comments&utm_term=apache).
<details><summary>Additional details and impacted files</summary>
```diff
@@ Coverage Diff @@
## develop #8436 +/- ##
=============================================
- Coverage 45.54% 45.48% -0.06%
+ Complexity 11031 11020 -11
=============================================
Files 1274 1274
Lines 88997 88997
Branches 11440 11440
=============================================
- Hits 40532 40481 -51
- Misses 43427 43467 +40
- Partials 5038 5049 +11
```
</details>
[:umbrella: View full report in Codecov by Sentry](https://app.codecov.io/gh/apache/rocketmq/pull/8436?dropdown=coverage&src=pr&el=continue&utm_medium=referral&utm_source=github&utm_content=comment&utm_campaign=pr+comments&utm_term=apache).
:loudspeaker: Have feedback on the report? [Share it here](https://about.codecov.io/codecov-pr-comment-feedback/?utm_medium=referral&utm_source=github&utm_content=comment&utm_campaign=pr+comments&utm_term=apache).
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: commits-unsubscribe@rocketmq.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org